## $Id: interfaces.py 17405 2023-05-08 17:21:10Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

from zope import schema
from waeup.kofa.students.vocabularies import StudyLevelSource
from waeup.kofa.interfaces import (IKofaObject, academic_sessions_vocab)
from waeup.kofa.schema import FormattedDate
from kofacustom.nigeria.students.interfaces import (
    INigeriaStudentBase, INigeriaUGStudentClearance, INigeriaPGStudentClearance,
    INigeriaStudentPersonal, INigeriaStudentStudyLevel,
    INigeriaStudentStudyCourse, INigeriaCourseTicket,
    INigeriaStudentUpdateByRegNo, INigeriaStudentUpdateByMatricNo,
    )
from kofacustom.edocons.payments.interfaces import ICustomOnlinePayment
from kofacustom.edocons.interfaces import MessageFactory as _

class ICustomStudentBase(INigeriaStudentBase):
    """Representation of student base data.

    """

class ICustomStudentPersonal(INigeriaStudentPersonal):
    """Student personal data.

    """

class ICustomUGStudentClearance(INigeriaUGStudentClearance):
    """Representation of ug student clearance data.

    """

class ICustomPGStudentClearance(INigeriaPGStudentClearance):
    """Representation of pg student clearance data.

    """


class ICustomStudent(ICustomStudentBase,ICustomUGStudentClearance,
    ICustomPGStudentClearance,ICustomStudentPersonal):
    """Representation of a student.

    """

class ICustomStudentStudyCourse(INigeriaStudentStudyCourse):
    """A container for student study levels.

    """

class ICustomStudentStudyLevel(INigeriaStudentStudyLevel):
    """A container for course tickets.

    """

class ICustomStudentOnlinePayment(ICustomOnlinePayment):
    """A student payment via payment gateways.

    This Interface does not inherit from IStudentOnlinePayment.
    Thus all fields from IStudentOnlinePayment have to be repeated here.
    """

    p_current = schema.Bool(
        title = _(u'Current Session Payment'),
        default = True,
        required = False,
        )

    p_level = schema.Choice(
        title = _(u'Payment Level'),
        source = StudyLevelSource(),
        required = False,
        )

ICustomStudentOnlinePayment['p_level'].order = ICustomStudentOnlinePayment[
    'p_session'].order

class ICustomCourseTicket(INigeriaCourseTicket):
    """A course ticket.

    """

    carryover_score = schema.Int(
        title = _(u'Carry-over Score'),
        default = None,
        required = False,
        missing_value = None,
        max = 100,
        )

    attempted_number = schema.Int(
        title = _(u'Attempted Number'),
        default = None,
        required = False,
        missing_value = None,
        max = 5,
        )

    rst_grade = schema.TextLine(
        title = _(u'RST Grade'),
        required = False,
        )

    in_progress = schema.Bool(
        title = _(u'Course in Progress'),
        default = False,
        required = False,
        )

    resumption_date = FormattedDate(
        title = _(u'Resumption Date'),
        required = False,
        show_year = True,
        )

ICustomCourseTicket['carryover_score'].order = ICustomCourseTicket['carry_over'].order
#ICustomCourseTicket['in_progress'].order = ICustomCourseTicket['grade'].order
#ICustomCourseTicket['resumption_date'].order = ICustomCourseTicket['grade'].order

class ICustomCourseTicketImport(ICustomCourseTicket):
    """An interface for importing course results and nothing more.
    """

    score = schema.Int(
        title = _(u'Score'),
        required = False,
        readonly = False,
        )

    level_session = schema.Choice(
        title = _(u'Level Session'),
        source = academic_sessions_vocab,
        required = False,
        readonly = False,
        )

class ICustomStudentUpdateByRegNo(INigeriaStudentUpdateByRegNo):
    """Representation of a student. Skip regular reg_number validation.

    """

class ICustomStudentUpdateByMatricNo(INigeriaStudentUpdateByMatricNo):
    """Representation of a student. Skip regular matric_number validation.

    """
